/*********************************************************************************
The following model is assumed: 

        Y_t|X_t ~ Exp[a * exp(X_t'*beta) ],

    where 

    1) Y_t is 1 * 1 scalar;
    2) X_t is k * 1 vector; and
    3) beta is k * 1 vector.

The unknown parameters are estimated by the MLE method. 
Given this, the following program computes two statistics:

    1) IMT tests defined by Cho and White (2011):

        b1, b2, and b3

       as defined by Cho and White (2011).  

    2) Estimated p-values of the tests by parametric bootstrap:

        pv1, pv2, pv3

       as explained in Cho and White (2011).

November 20, 2011
Jin Seo Cho
**************************************************************************************/
new;
library pgraph cml;
#include cml.ext;
#include trc.prc;
#include pdflinexp.prc;
#include imts_linexp.prc;
#include imts_linexp_pb.prc;

CMLset;
__output = 0;
_cml_DirTol = 0.000001;
_cml_GradProc = 0;

nnn = 200;                                                  /* sample size */
bbb = 100;                                                  /* number of bootstrapping */

xxx = rndn(nnn,2);                                          /* provide explanatory variable */
uuu = rndu(nnn,1);
yyy = -ln(uuu) ./(1*(exp(1*xxx[.,1]+1*xxx[.,2])));          /* provide dependent variable */
y   = ones(3,1);                                            /* provide initial parameter values for MLE */

dta = yyy~xxx;

{pame, h, g, cov, ret} = CML(dta, 0, &pdflinexp, y);        /* estimate MLE using CML procedures */
{b1, b2, b3}           = imts_linexp(dta, pame);            /* computes the test statistics */ 
{pv1, pv2, pv3}        = imts_linexp_pb(dta, bbb, pame, y); /* computes the p-values of the test statistics */


print "===============================================";
print "Linear Exponential Model                       ";
print "===============================================";
print "Computed test statsitics values"; 
print "===============================================";
print "Test Statistic B_1 =           " b1;
print "Test Statistic B_2 =           " b2;
print "Test Statistic B_3 =           " b3;
print "===============================================";
print "Computed P-values of test statsitics"; 
print "===============================================";
print "P-value of Test Statistic B_1 =" pv1;
print "P-value of Test Statistic B_2 =" pv2;
print "P-value of Test Statistic B_3 =" pv3;
print "===============================================";


